@@ -1,3 +1,4 @@
+#include <locale.h>
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-wall-clock.h>
 
@@ -17,6 +18,8 @@ int main (int argc, char **argv)
 	GMainLoop *loop;
 	GnomeWallClock *clock;
 
+        setlocale (LC_ALL, "");
+
 	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
 	loop = g_main_loop_new (NULL, FALSE);
@@ -25,6 +28,8 @@ int main (int argc, char **argv)
 	g_signal_connect (G_OBJECT (clock), "notify::clock",
 			  G_CALLBACK (clock_changed), NULL);
 
+	clock_changed (clock, NULL, NULL);
+
 	g_main_loop_run (loop);
 
 	return 0;
